@@ -1,10 +1,17 @@
 package Font::TTF::AATutils;
 
+=head1 NAME
+
+Font::TTF::AATutils
+
+=cut
+
 use strict;
 use vars qw(@ISA @EXPORT);
 require Exporter;
 
 use Font::TTF::Utils;
+use IO::File;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(
