@@ -38,6 +38,9 @@ those for which no special code exists, the table type C<table> is used, which
 defaults to L<Font::TTF::Table>. The current tables which are supported are:
 
     table       Font::TTF::Table      - for unknown tables
+    EBDT        Font::TTF::EBDT
+    EBLC        Font::TTF::EBLC
+    Feat        Font::TTF::GrFeat
     GDEF        Font::TTF::GDEF
     GPOS        Font::TTF::GPOS
     GSUB        Font::TTF::GSUB
@@ -69,7 +72,9 @@ defaults to L<Font::TTF::Table>. The current tables which are supported are:
 
 Links are:
 
-L<Font::TTF::Table> L<Font::TTF::GDEF> L<Font::TTF::GPOS> L<Font::TTF::GSUB> L<Font::TTF::LTSH>
+L<Font::TTF::Table> 
+L<Font::TTF::EBDT> L<Font::TTF::EBLC> L<Font::TTF::GrFeat>
+L<Font::TTF::GDEF> L<Font::TTF::GPOS> L<Font::TTF::GSUB> L<Font::TTF::LTSH>
 L<Font::TTF::OS_2> L<Font::TTF::PCLT> L<Font::TTF::Bsln> L<Font::TTF::Cmap> L<Font::TTF::Cvt_>
 L<Font::TTF::Fdsc> L<Font::TTF::Feat> L<Font::TTF::Fmtx> L<Font::TTF::Fpgm> L<Font::TTF::Glyf>
 L<Font::TTF::Hdmx> L<Font::TTF::Head> L<Font::TTF::Hhea> L<Font::TTF::Hmtx> L<Font::TTF::Kern>
@@ -91,6 +96,10 @@ This is used during output to disable the creation of the file checksum in the
 head table. For example, during DSIG table creation, this flag will be set to
 ensure that the file checksum is left at zero.
 
+=item noharmony
+
+If set, do not harmonize the script and lang trees of GPOS and GSUB tables. See L<Font::TTF::Ttopen> for more info.
+
 =item fname (R)
 
 Contains the filename of the font which this object was read from.
@@ -118,7 +127,10 @@ use Symbol();
 
 require 5.004;
 
-$VERSION = 0.34;    # MJPH      22-MAY-2003     Update PSNames to latest AGL
+$VERSION = 0.37;    # MJPH       7-OCT-2005     Force hhea update if dirty, give more OS/2 stuff in update
+# $VERSION = 0.36;    # MJPH      19-AUG-2005     Change cmap::reverse api to be opts based
+# $VERSION = 0.35;    # MJPH       4-MAY-2004     Various fixes to OpenType stuff, separate off scripts
+# $VERSION = 0.34;    # MJPH      22-MAY-2003     Update PSNames to latest AGL
 # $VERSION = 0.33;    # MJPH       9-OCT-2002     Support CFF OpenType (just by version=='OTTO'?!)
 # $VERSION = 0.32;    # MJPH       2-OCT-2002     Bug fixes to TTFBuilder, new methods and some
 #                                                 extension table support in Ttopen and Coverage
@@ -159,6 +171,9 @@ $VERSION = 0.34;    # MJPH      22-MAY-2003     Update PSNames to latest AGL
 
 %tables = (
         'table' => 'Font::TTF::Table',
+        'EBDT' => 'Font::TTF::EBDT',
+        'EBLC' => 'Font::TTF::EBLC',
+        'Feat' => 'Font::TTF::GrFeat',
         'GDEF' => 'Font::TTF::GDEF',
         'GPOS' => 'Font::TTF::GPOS',
         'GSUB' => 'Font::TTF::GSUB',
@@ -241,7 +256,7 @@ sub Init
     my ($class) = @_;
     my ($t);
 
-    foreach $t (keys %tables)
+    foreach $t (values %tables)
     {
         $t =~ s|::|/|oig;
         require "$t.pm";
@@ -441,7 +456,7 @@ sub out
         }
         $dir{$k} = pack("A4NNN", $k, $csum, $oldloc, $len);
         $msum += $csum + unpack("%32N*", $dir{$k});
-        if ($msum > 0xffffffff) { $msum -= 0xffffffff; $msum--; }
+        while ($msum > 0xffffffff) { $msum -= 0xffffffff; $msum--; }
         $fh->seek($loc, 0);
     }
 
@@ -612,21 +627,23 @@ Dirties all the tables in the font
 sub dirty
 { $_[0]->tables_do(sub { $_[0]->dirty; }); $_[0]; }
 
-=head2 $f->tables_do(&func)
+=head2 $f->tables_do(&func [, tables])
 
 Calls &func for each table in the font. Calls the table in alphabetical sort
 order as per the order in the directory:
 
     &func($table, $name);
 
+May optionally take a list of table names in which case func is called
+for each of them in the given order.
 =cut
 
 sub tables_do
 {
-    my ($self, $func) = @_;
+    my ($self, $func, @tables) = @_;
     my ($t);
 
-    foreach $t (sort grep {length($_) == 4} keys %$self)
+    foreach $t (@tables ? @tables : sort grep {length($_) == 4} keys %$self)
     { &$func($self->{$t}, $t); }
     $self;
 }
